pyparsing.pyparsing.White

Package pyparsing :: Module pyparsing :: Class White |
[frames | no frames]

## Type White

       object --+
                |
    ParserElement --+
                    |
                Token --+
                        |
                       White

Special matching class for matching whitespace. Normally, whitespace is ignored by pyparsing grammars. This class is included when some whitespace structures are significant. Define with a string containing the whitespace characters to be matched; default is " \t\n". Also takes optional min, max, and exact arguments, as defined for the Word class.

Method Summary
| `__init__(self, ws, min, max, exact)`
| `parseImpl(self, instring, loc, doActions)`
Inherited from `Token`: `setName` Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__getattr__`, `__invert__`, `__mul__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__ror__`, `__rxor__`, `__str__`, `__xor__`, `addParseAction`, `checkRecursion`, `copy`, `enablePackrat`, `getException`, `ignore`, `leaveWhitespace`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `resetCache`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `streamline`, `suppress`, `transformString`, `tryParse`, `validate` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
`dict` | `whiteStrs` = `{'\t': '<TAB>', ' ': '<SPC>', '\n': '<LF>', ...`
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Class Variable Details

    ### whiteStrs Type: `dict` Value:
        {'\t': '<TAB>', '\n': '<LF>', '\x0c': '<FF>', '\r': '<CR>', ' ': '<SPC\
        >'}

Generated by Epydoc 2.1 on Sun Feb 10 18:01:06 2008 | http://epydoc.sf.net